// Use this file to define constants that will be used by multiple files in the
// erosion process. This will also define functions that will be used by 
// multiple files.
#ifndef __CONSTANTS__
#define __CONSTANTS__

#include <math.h>
#include <stdlib.h>

// Variable Definitions:

// The max percent eroded we want the system to be
const double GOAL = 60.00;

// Step to the next percent eroded to print
const double PERCENT_STEP = 0.25;

// The discritization value in X
const double DX = 1.0; 

// The derivation of the code assumes square grids
const double DY = DX; 

// LENGTH => units in x direction
const int LENGTH = 101;

// WIDTH => units in y direction
const int WIDTH = 101;

// The water level at the base of the ridge
const double WATER_LEVEL = 5.0;

// The time step to use for water equilibrium
const double TIME_STEP = 0.001;

// The Rainfall rate 
const double RAINFALL = ( 5.0/360000.0 );

// The scaling paramater
const double SCALING = 0.5;

// Tolerance for the water depth
const double TOLERANCE = pow( 10.0, -6.0 );

// The Manning number
const double MANNING = 33.3;

// Constants from the sediment flow
const double GAMMA = 2.0;
const double DELTA = 2.0;

// Erosion parameter
const double K = 500000.0;

// Constants of the sediment flow equation
const double B = (5.0/3.0)*GAMMA;
const double C = DELTA + GAMMA/2.0 - 1;
const double E = K*pow( MANNING, GAMMA );

// Function Definitions:
// These functions will remove the need to use nested if statements because of
// the boundary conditions.

// Used in the function definitions
#define max(a, b) (((a) > (b)) ? (a) : (b))

// The location to the left of (i, j) ~= (i-1, j)
inline int LEFT (int i) {
        return ( ( i - 1 + LENGTH ) % ( LENGTH ) );
}

// The location to the right of (i, j) ~= (i+1, j)
inline int RIGHT (int i) {
	return ( ( i + 1 ) % ( LENGTH ) );
}

// The location above (i, j) ~= (i, j+1)
inline int UP (int j) {
	return (WIDTH - 1 - abs( WIDTH - j - 2 ));
} 

// The location below (i, j) ~= (i, j-1)
inline int DOWN (int j) {
	return max(j-1, 0);
}

#endif
