/*******************************************************************************
 *
 * The following code will generate an initial wedge shaped hill to start the
 * erosion process. The parameter 'grade' is (essentially) the slope of the 
 * hillside.
 *
 * The code will generate a LENGTHxWIDTH array where LENGTH and WIDTH are the 
 * parameters from the constants header file.
 *
 ******************************************************************************/

/* System needed files */
#include <stdlib.h>
#include <time.h>

/* User define files */
#include "constants.h"
#include "write_data.h"

int main ( int argc, char **argv )
{
  // Create a variable for the initial hillside
  double H[LENGTH][WIDTH] = {};
  // Create a variable for the initial water depth
  double h[LENGTH][WIDTH] = {};

  // Get the grade of the hill
  double grade = atof( argv[1] );

  // Create a variable for random change
  double pert = 0.0;

  // Initialize the random number generator
  srand( time(NULL) );

  // Generate the hillside and water depth
  // Also, calculate the volume as we go
  double volume = 0.0;
  for ( int i=0;  i<LENGTH; i++ )
  {
    for ( int j=0; j<WIDTH; j++ )
    {
      h[i][j] = 0.1 - j*(0.1/(WIDTH-1));
      H[i][j] = WATER_LEVEL + j*(grade/(WIDTH-1));

      // Perturbations need to be added to the surface for stability.
      // However, less than 20% of locations need a perturbation.
      // Determine if this is one of the lucky spots
      pert = ((double) rand()/(RAND_MAX));
      if ( (pert < 0.20) && (j > 0) && (j < WIDTH-1) )
      {
        H[i][j] += 0.01*((double) rand()/(RAND_MAX));
      }

      // Add the volume from this square
      volume += (H[i][j] - WATER_LEVEL)*DX*DY;
    }
  }

  // Now write the data to a file
  write_data( "Hill_Data.txt", 1, 0.25, volume, H, h );

  // Done.
  return 0;
}
