/******************************************************************************
 *
 * This function will be commonly called during the sediment flow stage of the
 * code. It takes data from the water depth and water surface variables and
 * converts it into an array to be used when creating the various tridiagonal
 * systems solved in this process.
 *
 *****************************************************************************/
#include "getXY.h"

int getXY( int i, int j, double XY[2][21], double H[LENGTH][WIDTH], double h[LENGTH][WIDTH] )
{
  for ( int q=0; q < 2; q++ )
  {
    // The first 7 values depend on the value of q (q=0 -> X, q=1 -> Y)
    if ( q == 0 )
    {
      XY[q][0] = ( H[RIGHT(i)][j] - H[LEFT(i)][j] )/(2*DX);
      XY[q][1] = ( H[RIGHT(i)][UP(j)] + H[i][UP(j)] - H[i][DOWN(j)] - H[RIGHT(i)][DOWN(j)] )/(4.0*DX);
      XY[q][2] = ( H[LEFT(i)][UP(j)] + H[i][UP(j)] - H[i][DOWN(j)] - H[LEFT(i)][DOWN(j)] )/(4.0*DX);
      XY[q][3] = pow( ( h[RIGHT(i)][j] + h[i][j] )/2.0, B );
      XY[q][4] = pow( ( h[LEFT(i)][j] + h[i][j] )/2.0, B );
      XY[q][5] = ( H[RIGHT(i)][j] - H[i][j] )/DX;
      XY[q][6] = ( H[i][j] - H[LEFT(i)][j] )/DX;
    } else {
      XY[q][0] = ( H[i][UP(j)] - H[i][DOWN(j)])/(2*DY);
      XY[q][1] = ( H[RIGHT(i)][UP(j)] + H[RIGHT(i)][j] - H[LEFT(i)][UP(j)] - H[LEFT(i)][j] )/(4.0*DY);
      XY[q][2] = ( H[RIGHT(i)][DOWN(j)] + H[RIGHT(i)][j] - H[LEFT(i)][j] - H[LEFT(i)][DOWN(j)] )/(4.0*DY);
      XY[q][3] = pow( ( h[i][UP(j)] + h[i][j] )/2.0, B );
      XY[q][4] = pow( ( h[i][DOWN(j)] + h[i][j] )/2.0, B );
      XY[q][5] = ( H[i][UP(j)] - H[i][j] )/DY;
      XY[q][6] = ( H[i][j] - H[i][DOWN(j)] )/DY;
    }
    // The remaining values are all calculated in the same fashion thanks to
    // clever choices for the first 7 variables
    XY[q][7] = pow( XY[q][5], 2.0 ) + pow( XY[q][1], 2.0 );
    XY[q][8] = pow( XY[q][7], C/2.0 - 1.0 );
    XY[q][9] = XY[q][7]*XY[q][8];
    XY[q][10] = pow( XY[q][6], 2.0 ) + pow( XY[q][2], 2.0 );
    XY[q][11] = pow( XY[q][10], C/2.0 - 1.0 );
    XY[q][12] = XY[q][10]*XY[q][11];
    XY[q][13] = XY[q][3]*XY[q][9];
    XY[q][14] = XY[q][4]*XY[q][12];
    XY[q][15] = C*XY[q][3]*XY[q][5]*XY[q][8];
    XY[q][16] = XY[q][5]*XY[q][15];
    XY[q][17] = XY[q][1]*XY[q][15];
    XY[q][18] = C*XY[q][4]*XY[q][6]*XY[q][11];
    XY[q][19] = XY[q][6]*XY[q][18];
    XY[q][20] = XY[q][2]*XY[q][18];
  }

  return 1;
}
